from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import accelerometer_pb2 as _accelerometer_pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import agent_state_pb2 as _agent_state_pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import force_resistance_pb2 as _force_resistance_pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import game_state_pb2 as _game_state_pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import gyro_rate_pb2 as _gyro_rate_pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import hear_pb2 as _hear_pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import hinge_joint_pos_pb2 as _hinge_joint_pos_pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import universal_joint_pos_pb2 as _universal_joint_pos_pb2
from make87_messages_ros2.humble.rcss3d_agent_msgs.msg import vision_pb2 as _vision_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Percept(_message.Message):
    __slots__ = ["header", "gyro_rates", "hinge_joints", "universal_joints", "force_resistances", "accelerometers", "vision", "game_state", "agent_state", "hears"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    GYRO_RATES_FIELD_NUMBER: _ClassVar[int]
    HINGE_JOINTS_FIELD_NUMBER: _ClassVar[int]
    UNIVERSAL_JOINTS_FIELD_NUMBER: _ClassVar[int]
    FORCE_RESISTANCES_FIELD_NUMBER: _ClassVar[int]
    ACCELEROMETERS_FIELD_NUMBER: _ClassVar[int]
    VISION_FIELD_NUMBER: _ClassVar[int]
    GAME_STATE_FIELD_NUMBER: _ClassVar[int]
    AGENT_STATE_FIELD_NUMBER: _ClassVar[int]
    HEARS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    gyro_rates: _containers.RepeatedCompositeFieldContainer[_gyro_rate_pb2.GyroRate]
    hinge_joints: _containers.RepeatedCompositeFieldContainer[_hinge_joint_pos_pb2.HingeJointPos]
    universal_joints: _containers.RepeatedCompositeFieldContainer[_universal_joint_pos_pb2.UniversalJointPos]
    force_resistances: _containers.RepeatedCompositeFieldContainer[_force_resistance_pb2.ForceResistance]
    accelerometers: _containers.RepeatedCompositeFieldContainer[_accelerometer_pb2.Accelerometer]
    vision: _containers.RepeatedCompositeFieldContainer[_vision_pb2.Vision]
    game_state: _game_state_pb2.GameState
    agent_state: _containers.RepeatedCompositeFieldContainer[_agent_state_pb2.AgentState]
    hears: _containers.RepeatedCompositeFieldContainer[_hear_pb2.Hear]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., gyro_rates: _Optional[_Iterable[_Union[_gyro_rate_pb2.GyroRate, _Mapping]]] = ..., hinge_joints: _Optional[_Iterable[_Union[_hinge_joint_pos_pb2.HingeJointPos, _Mapping]]] = ..., universal_joints: _Optional[_Iterable[_Union[_universal_joint_pos_pb2.UniversalJointPos, _Mapping]]] = ..., force_resistances: _Optional[_Iterable[_Union[_force_resistance_pb2.ForceResistance, _Mapping]]] = ..., accelerometers: _Optional[_Iterable[_Union[_accelerometer_pb2.Accelerometer, _Mapping]]] = ..., vision: _Optional[_Iterable[_Union[_vision_pb2.Vision, _Mapping]]] = ..., game_state: _Optional[_Union[_game_state_pb2.GameState, _Mapping]] = ..., agent_state: _Optional[_Iterable[_Union[_agent_state_pb2.AgentState, _Mapping]]] = ..., hears: _Optional[_Iterable[_Union[_hear_pb2.Hear, _Mapping]]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class DeviceInfoRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DeviceInfoResponse(_message.Message):
    __slots__ = ["device_name", "serial_number", "firmware_version", "usb_type_descriptor", "firmware_update_id", "sensors", "physical_port"]
    DEVICE_NAME_FIELD_NUMBER: _ClassVar[int]
    SERIAL_NUMBER_FIELD_NUMBER: _ClassVar[int]
    FIRMWARE_VERSION_FIELD_NUMBER: _ClassVar[int]
    USB_TYPE_DESCRIPTOR_FIELD_NUMBER: _ClassVar[int]
    FIRMWARE_UPDATE_ID_FIELD_NUMBER: _ClassVar[int]
    SENSORS_FIELD_NUMBER: _ClassVar[int]
    PHYSICAL_PORT_FIELD_NUMBER: _ClassVar[int]
    device_name: str
    serial_number: str
    firmware_version: str
    usb_type_descriptor: str
    firmware_update_id: str
    sensors: str
    physical_port: str
    def __init__(self, device_name: _Optional[str] = ..., serial_number: _Optional[str] = ..., firmware_version: _Optional[str] = ..., usb_type_descriptor: _Optional[str] = ..., firmware_update_id: _Optional[str] = ..., sensors: _Optional[str] = ..., physical_port: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rosapi_msgs/srv/service_node.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/rolling/rosapi_msgs/srv/service_node.proto\x12,make87_messages_ros2.rolling.rosapi_msgs.srv\"%\n\x12ServiceNodeRequest\x12\x0f\n\x07service\x18\x01 \x01(\t\"#\n\x13ServiceNodeResponse\x12\x0c\n\x04node\x18\x01 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rosapi_msgs.srv.service_node_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SERVICENODEREQUEST']._serialized_start=113
  _globals['_SERVICENODEREQUEST']._serialized_end=150
  _globals['_SERVICENODERESPONSE']._serialized_start=152
  _globals['_SERVICENODERESPONSE']._serialized_end=187
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class CfgRATE(_message.Message):
    __slots__ = ["meas_rate", "nav_rate", "time_ref"]
    MEAS_RATE_FIELD_NUMBER: _ClassVar[int]
    NAV_RATE_FIELD_NUMBER: _ClassVar[int]
    TIME_REF_FIELD_NUMBER: _ClassVar[int]
    meas_rate: int
    nav_rate: int
    time_ref: int
    def __init__(self, meas_rate: _Optional[int] = ..., nav_rate: _Optional[int] = ..., time_ref: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rosbridge_msgs/msg/connected_client.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFmake87_messages_ros2/rolling/rosbridge_msgs/msg/connected_client.proto\x12/make87_messages_ros2.rolling.rosbridge_msgs.msg\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\"y\n\x0f\x43onnectedClient\x12\x12\n\nip_address\x18\x01 \x01(\t\x12R\n\x0f\x63onnection_time\x18\x02 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Timeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rosbridge_msgs.msg.connected_client_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CONNECTEDCLIENT']._serialized_start=187
  _globals['_CONNECTEDCLIENT']._serialized_end=308
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.ur_dashboard_msgs.msg import safety_mode_pb2 as _safety_mode_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetSafetyModeRequest(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GetSafetyModeResponse(_message.Message):
    __slots__ = ["safety_mode", "answer", "success"]
    SAFETY_MODE_FIELD_NUMBER: _ClassVar[int]
    ANSWER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    safety_mode: _safety_mode_pb2.SafetyMode
    answer: str
    success: bool
    def __init__(self, safety_mode: _Optional[_Union[_safety_mode_pb2.SafetyMode, _Mapping]] = ..., answer: _Optional[str] = ..., success: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_fleet_msgs/msg/speed_limit_request.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rmf_fleet_msgs.msg import speed_limited_lane_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__fleet__msgs_dot_msg_dot_speed__limited__lane__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/jazzy/rmf_fleet_msgs/msg/speed_limit_request.proto\x12-make87_messages_ros2.jazzy.rmf_fleet_msgs.msg\x1a\x46make87_messages_ros2/jazzy/rmf_fleet_msgs/msg/speed_limited_lane.proto\"\x95\x01\n\x11SpeedLimitRequest\x12\x12\n\nfleet_name\x18\x01 \x01(\t\x12U\n\x0cspeed_limits\x18\x02 \x03(\x0b\x32?.make87_messages_ros2.jazzy.rmf_fleet_msgs.msg.SpeedLimitedLane\x12\x15\n\rremove_limits\x18\x03 \x03(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_fleet_msgs.msg.speed_limit_request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SPEEDLIMITREQUEST']._serialized_start=195
  _globals['_SPEEDLIMITREQUEST']._serialized_end=344
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Digital(_message.Message):
    __slots__ = ["pin", "state"]
    PIN_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    pin: int
    state: bool
    def __init__(self, pin: _Optional[int] = ..., state: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/sensor_msgs/msg/camera_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.sensor_msgs.msg import region_of_interest_pb2 as make87__messages__ros2_dot_humble_dot_sensor__msgs_dot_msg_dot_region__of__interest__pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_humble_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/humble/sensor_msgs/msg/camera_info.proto\x12+make87_messages_ros2.humble.sensor_msgs.msg\x1a!make87_messages/core/header.proto\x1a\x44make87_messages_ros2/humble/sensor_msgs/msg/region_of_interest.proto\x1a\x35make87_messages_ros2/humble/std_msgs/msg/header.proto\"\xd8\x02\n\nCameraInfo\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x45\n\x0bros2_header\x18\x02 \x01(\x0b\x32\x30.make87_messages_ros2.humble.std_msgs.msg.Header\x12\x0e\n\x06height\x18\x03 \x01(\r\x12\r\n\x05width\x18\x04 \x01(\r\x12\x18\n\x10\x64istortion_model\x18\x05 \x01(\t\x12\t\n\x01\x64\x18\x06 \x03(\x01\x12\t\n\x01k\x18\x07 \x03(\x01\x12\t\n\x01r\x18\x08 \x03(\x01\x12\t\n\x01p\x18\t \x03(\x01\x12\x11\n\tbinning_x\x18\n \x01(\r\x12\x11\n\tbinning_y\x18\x0b \x01(\r\x12J\n\x03roi\x18\x0c \x01(\x0b\x32=.make87_messages_ros2.humble.sensor_msgs.msg.RegionOfInterestb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.sensor_msgs.msg.camera_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CAMERAINFO']._serialized_start=271
  _globals['_CAMERAINFO']._serialized_end=615
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Mavlink(_message.Message):
    __slots__ = ["header", "framing_status", "magic", "len", "incompat_flags", "compat_flags", "seq", "sysid", "compid", "msgid", "checksum", "payload64", "signature"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    FRAMING_STATUS_FIELD_NUMBER: _ClassVar[int]
    MAGIC_FIELD_NUMBER: _ClassVar[int]
    LEN_FIELD_NUMBER: _ClassVar[int]
    INCOMPAT_FLAGS_FIELD_NUMBER: _ClassVar[int]
    COMPAT_FLAGS_FIELD_NUMBER: _ClassVar[int]
    SEQ_FIELD_NUMBER: _ClassVar[int]
    SYSID_FIELD_NUMBER: _ClassVar[int]
    COMPID_FIELD_NUMBER: _ClassVar[int]
    MSGID_FIELD_NUMBER: _ClassVar[int]
    CHECKSUM_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD64_FIELD_NUMBER: _ClassVar[int]
    SIGNATURE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    framing_status: int
    magic: int
    len: int
    incompat_flags: int
    compat_flags: int
    seq: int
    sysid: int
    compid: int
    msgid: int
    checksum: int
    payload64: _containers.RepeatedScalarFieldContainer[int]
    signature: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., framing_status: _Optional[int] = ..., magic: _Optional[int] = ..., len: _Optional[int] = ..., incompat_flags: _Optional[int] = ..., compat_flags: _Optional[int] = ..., seq: _Optional[int] = ..., sysid: _Optional[int] = ..., compid: _Optional[int] = ..., msgid: _Optional[int] = ..., checksum: _Optional[int] = ..., payload64: _Optional[_Iterable[int]] = ..., signature: _Optional[_Iterable[int]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rcl_interfaces/srv/describe_parameters.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.rcl_interfaces.msg import parameter_descriptor_pb2 as make87__messages__ros2_dot_humble_dot_rcl__interfaces_dot_msg_dot_parameter__descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/humble/rcl_interfaces/srv/describe_parameters.proto\x12.make87_messages_ros2.humble.rcl_interfaces.srv\x1a!make87_messages/core/header.proto\x1aImake87_messages_ros2/humble/rcl_interfaces/msg/parameter_descriptor.proto\"X\n\x19\x44\x65scribeParametersRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\r\n\x05names\x18\x02 \x03(\t\"\xa4\x01\n\x1a\x44\x65scribeParametersResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12X\n\x0b\x64\x65scriptors\x18\x02 \x03(\x0b\x32\x43.make87_messages_ros2.humble.rcl_interfaces.msg.ParameterDescriptorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rcl_interfaces.srv.describe_parameters_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_DESCRIBEPARAMETERSREQUEST']._serialized_start=234
  _globals['_DESCRIBEPARAMETERSREQUEST']._serialized_end=322
  _globals['_DESCRIBEPARAMETERSRESPONSE']._serialized_start=325
  _globals['_DESCRIBEPARAMETERSRESPONSE']._serialized_end=489
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class NewRos2MqttBridgeRequest(_message.Message):
    __slots__ = ["ros_topic", "mqtt_topic", "primitive", "inject_timestamp", "ros_queue_size", "mqtt_qos", "mqtt_retained"]
    ROS_TOPIC_FIELD_NUMBER: _ClassVar[int]
    MQTT_TOPIC_FIELD_NUMBER: _ClassVar[int]
    PRIMITIVE_FIELD_NUMBER: _ClassVar[int]
    INJECT_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    ROS_QUEUE_SIZE_FIELD_NUMBER: _ClassVar[int]
    MQTT_QOS_FIELD_NUMBER: _ClassVar[int]
    MQTT_RETAINED_FIELD_NUMBER: _ClassVar[int]
    ros_topic: str
    mqtt_topic: str
    primitive: bool
    inject_timestamp: bool
    ros_queue_size: int
    mqtt_qos: int
    mqtt_retained: bool
    def __init__(self, ros_topic: _Optional[str] = ..., mqtt_topic: _Optional[str] = ..., primitive: bool = ..., inject_timestamp: bool = ..., ros_queue_size: _Optional[int] = ..., mqtt_qos: _Optional[int] = ..., mqtt_retained: bool = ...) -> None: ...

class NewRos2MqttBridgeResponse(_message.Message):
    __slots__ = ["success"]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Field(_message.Message):
    __slots__ = ["ranges", "start_angle", "angular_resolution", "protective_field"]
    RANGES_FIELD_NUMBER: _ClassVar[int]
    START_ANGLE_FIELD_NUMBER: _ClassVar[int]
    ANGULAR_RESOLUTION_FIELD_NUMBER: _ClassVar[int]
    PROTECTIVE_FIELD_FIELD_NUMBER: _ClassVar[int]
    ranges: _containers.RepeatedScalarFieldContainer[float]
    start_angle: float
    angular_resolution: float
    protective_field: bool
    def __init__(self, ranges: _Optional[_Iterable[float]] = ..., start_angle: _Optional[float] = ..., angular_resolution: _Optional[float] = ..., protective_field: bool = ...) -> None: ...



from make87_messages_ros2.jazzy.ibeo_msgs.msg import ibeo_data_header_pb2 as _ibeo_data_header_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ErrorWarning(_message.Message):
    __slots__ = ["header", "ibeo_header", "err_internal_error", "err_motor_1_fault", "err_buffer_error_xmt_incomplete", "err_buffer_error_overflow", "err_apd_over_temperature", "err_apd_under_temperature", "err_apd_temperature_sensor_defect", "err_motor_2_fault", "err_motor_3_fault", "err_motor_4_fault", "err_motor_5_fault", "err_int_no_scan_data", "err_int_communication_error", "err_int_incorrect_scan_data", "err_config_fpga_not_configurable", "err_config_incorrect_config_data", "err_config_contains_incorrect_params", "err_timeout_data_processing", "err_timeout_env_model_computation_reset", "wrn_int_communication_error", "wrn_low_temperature", "wrn_high_temperature", "wrn_int_motor_1", "wrn_sync_error", "wrn_laser_1_start_pulse_missing", "wrn_laser_2_start_pulse_missing", "wrn_can_interface_blocked", "wrn_eth_interface_blocked", "wrn_incorrect_can_data_rcvd", "wrn_int_incorrect_scan_data", "wrn_eth_unkwn_incomplete_data", "wrn_incorrect_or_forbidden_cmd_rcvd", "wrn_memory_access_failure", "wrn_int_overflow", "wrn_ego_motion_data_missing", "wrn_incorrect_mounting_params", "wrn_no_obj_comp_due_to_scan_freq"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    IBEO_HEADER_FIELD_NUMBER: _ClassVar[int]
    ERR_INTERNAL_ERROR_FIELD_NUMBER: _ClassVar[int]
    ERR_MOTOR_1_FAULT_FIELD_NUMBER: _ClassVar[int]
    ERR_BUFFER_ERROR_XMT_INCOMPLETE_FIELD_NUMBER: _ClassVar[int]
    ERR_BUFFER_ERROR_OVERFLOW_FIELD_NUMBER: _ClassVar[int]
    ERR_APD_OVER_TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    ERR_APD_UNDER_TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    ERR_APD_TEMPERATURE_SENSOR_DEFECT_FIELD_NUMBER: _ClassVar[int]
    ERR_MOTOR_2_FAULT_FIELD_NUMBER: _ClassVar[int]
    ERR_MOTOR_3_FAULT_FIELD_NUMBER: _ClassVar[int]
    ERR_MOTOR_4_FAULT_FIELD_NUMBER: _ClassVar[int]
    ERR_MOTOR_5_FAULT_FIELD_NUMBER: _ClassVar[int]
    ERR_INT_NO_SCAN_DATA_FIELD_NUMBER: _ClassVar[int]
    ERR_INT_COMMUNICATION_ERROR_FIELD_NUMBER: _ClassVar[int]
    ERR_INT_INCORRECT_SCAN_DATA_FIELD_NUMBER: _ClassVar[int]
    ERR_CONFIG_FPGA_NOT_CONFIGURABLE_FIELD_NUMBER: _ClassVar[int]
    ERR_CONFIG_INCORRECT_CONFIG_DATA_FIELD_NUMBER: _ClassVar[int]
    ERR_CONFIG_CONTAINS_INCORRECT_PARAMS_FIELD_NUMBER: _ClassVar[int]
    ERR_TIMEOUT_DATA_PROCESSING_FIELD_NUMBER: _ClassVar[int]
    ERR_TIMEOUT_ENV_MODEL_COMPUTATION_RESET_FIELD_NUMBER: _ClassVar[int]
    WRN_INT_COMMUNICATION_ERROR_FIELD_NUMBER: _ClassVar[int]
    WRN_LOW_TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    WRN_HIGH_TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    WRN_INT_MOTOR_1_FIELD_NUMBER: _ClassVar[int]
    WRN_SYNC_ERROR_FIELD_NUMBER: _ClassVar[int]
    WRN_LASER_1_START_PULSE_MISSING_FIELD_NUMBER: _ClassVar[int]
    WRN_LASER_2_START_PULSE_MISSING_FIELD_NUMBER: _ClassVar[int]
    WRN_CAN_INTERFACE_BLOCKED_FIELD_NUMBER: _ClassVar[int]
    WRN_ETH_INTERFACE_BLOCKED_FIELD_NUMBER: _ClassVar[int]
    WRN_INCORRECT_CAN_DATA_RCVD_FIELD_NUMBER: _ClassVar[int]
    WRN_INT_INCORRECT_SCAN_DATA_FIELD_NUMBER: _ClassVar[int]
    WRN_ETH_UNKWN_INCOMPLETE_DATA_FIELD_NUMBER: _ClassVar[int]
    WRN_INCORRECT_OR_FORBIDDEN_CMD_RCVD_FIELD_NUMBER: _ClassVar[int]
    WRN_MEMORY_ACCESS_FAILURE_FIELD_NUMBER: _ClassVar[int]
    WRN_INT_OVERFLOW_FIELD_NUMBER: _ClassVar[int]
    WRN_EGO_MOTION_DATA_MISSING_FIELD_NUMBER: _ClassVar[int]
    WRN_INCORRECT_MOUNTING_PARAMS_FIELD_NUMBER: _ClassVar[int]
    WRN_NO_OBJ_COMP_DUE_TO_SCAN_FREQ_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ibeo_header: _ibeo_data_header_pb2.IbeoDataHeader
    err_internal_error: bool
    err_motor_1_fault: bool
    err_buffer_error_xmt_incomplete: bool
    err_buffer_error_overflow: bool
    err_apd_over_temperature: bool
    err_apd_under_temperature: bool
    err_apd_temperature_sensor_defect: bool
    err_motor_2_fault: bool
    err_motor_3_fault: bool
    err_motor_4_fault: bool
    err_motor_5_fault: bool
    err_int_no_scan_data: bool
    err_int_communication_error: bool
    err_int_incorrect_scan_data: bool
    err_config_fpga_not_configurable: bool
    err_config_incorrect_config_data: bool
    err_config_contains_incorrect_params: bool
    err_timeout_data_processing: bool
    err_timeout_env_model_computation_reset: bool
    wrn_int_communication_error: bool
    wrn_low_temperature: bool
    wrn_high_temperature: bool
    wrn_int_motor_1: bool
    wrn_sync_error: bool
    wrn_laser_1_start_pulse_missing: bool
    wrn_laser_2_start_pulse_missing: bool
    wrn_can_interface_blocked: bool
    wrn_eth_interface_blocked: bool
    wrn_incorrect_can_data_rcvd: bool
    wrn_int_incorrect_scan_data: bool
    wrn_eth_unkwn_incomplete_data: bool
    wrn_incorrect_or_forbidden_cmd_rcvd: bool
    wrn_memory_access_failure: bool
    wrn_int_overflow: bool
    wrn_ego_motion_data_missing: bool
    wrn_incorrect_mounting_params: bool
    wrn_no_obj_comp_due_to_scan_freq: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ibeo_header: _Optional[_Union[_ibeo_data_header_pb2.IbeoDataHeader, _Mapping]] = ..., err_internal_error: bool = ..., err_motor_1_fault: bool = ..., err_buffer_error_xmt_incomplete: bool = ..., err_buffer_error_overflow: bool = ..., err_apd_over_temperature: bool = ..., err_apd_under_temperature: bool = ..., err_apd_temperature_sensor_defect: bool = ..., err_motor_2_fault: bool = ..., err_motor_3_fault: bool = ..., err_motor_4_fault: bool = ..., err_motor_5_fault: bool = ..., err_int_no_scan_data: bool = ..., err_int_communication_error: bool = ..., err_int_incorrect_scan_data: bool = ..., err_config_fpga_not_configurable: bool = ..., err_config_incorrect_config_data: bool = ..., err_config_contains_incorrect_params: bool = ..., err_timeout_data_processing: bool = ..., err_timeout_env_model_computation_reset: bool = ..., wrn_int_communication_error: bool = ..., wrn_low_temperature: bool = ..., wrn_high_temperature: bool = ..., wrn_int_motor_1: bool = ..., wrn_sync_error: bool = ..., wrn_laser_1_start_pulse_missing: bool = ..., wrn_laser_2_start_pulse_missing: bool = ..., wrn_can_interface_blocked: bool = ..., wrn_eth_interface_blocked: bool = ..., wrn_incorrect_can_data_rcvd: bool = ..., wrn_int_incorrect_scan_data: bool = ..., wrn_eth_unkwn_incomplete_data: bool = ..., wrn_incorrect_or_forbidden_cmd_rcvd: bool = ..., wrn_memory_access_failure: bool = ..., wrn_int_overflow: bool = ..., wrn_ego_motion_data_missing: bool = ..., wrn_incorrect_mounting_params: bool = ..., wrn_no_obj_comp_due_to_scan_freq: bool = ...) -> None: ...



from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ChronyTrackingStatus(_message.Message):
    __slots__ = ["header", "reference", "stratum", "system_time_offset", "last_offset", "rms_offset", "frequency_offset", "residual_frequency", "skew", "root_delay", "root_dispersion", "update_interval", "leap_status"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_FIELD_NUMBER: _ClassVar[int]
    STRATUM_FIELD_NUMBER: _ClassVar[int]
    SYSTEM_TIME_OFFSET_FIELD_NUMBER: _ClassVar[int]
    LAST_OFFSET_FIELD_NUMBER: _ClassVar[int]
    RMS_OFFSET_FIELD_NUMBER: _ClassVar[int]
    FREQUENCY_OFFSET_FIELD_NUMBER: _ClassVar[int]
    RESIDUAL_FREQUENCY_FIELD_NUMBER: _ClassVar[int]
    SKEW_FIELD_NUMBER: _ClassVar[int]
    ROOT_DELAY_FIELD_NUMBER: _ClassVar[int]
    ROOT_DISPERSION_FIELD_NUMBER: _ClassVar[int]
    UPDATE_INTERVAL_FIELD_NUMBER: _ClassVar[int]
    LEAP_STATUS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    reference: str
    stratum: int
    system_time_offset: float
    last_offset: float
    rms_offset: float
    frequency_offset: float
    residual_frequency: float
    skew: float
    root_delay: float
    root_dispersion: float
    update_interval: float
    leap_status: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., reference: _Optional[str] = ..., stratum: _Optional[int] = ..., system_time_offset: _Optional[float] = ..., last_offset: _Optional[float] = ..., rms_offset: _Optional[float] = ..., frequency_offset: _Optional[float] = ..., residual_frequency: _Optional[float] = ..., skew: _Optional[float] = ..., root_delay: _Optional[float] = ..., root_dispersion: _Optional[float] = ..., update_interval: _Optional[float] = ..., leap_status: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/lifecycle_msgs/srv/get_available_states.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.lifecycle_msgs.msg import state_pb2 as make87__messages__ros2_dot_humble_dot_lifecycle__msgs_dot_msg_dot_state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/humble/lifecycle_msgs/srv/get_available_states.proto\x12.make87_messages_ros2.humble.lifecycle_msgs.srv\x1a!make87_messages/core/header.proto\x1a:make87_messages_ros2/humble/lifecycle_msgs/msg/state.proto\"I\n\x19GetAvailableStatesRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\"\x9b\x01\n\x1aGetAvailableStatesResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12O\n\x10\x61vailable_states\x18\x02 \x03(\x0b\x32\x35.make87_messages_ros2.humble.lifecycle_msgs.msg.Stateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.lifecycle_msgs.srv.get_available_states_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETAVAILABLESTATESREQUEST']._serialized_start=220
  _globals['_GETAVAILABLESTATESREQUEST']._serialized_end=293
  _globals['_GETAVAILABLESTATESRESPONSE']._serialized_start=296
  _globals['_GETAVAILABLESTATESRESPONSE']._serialized_end=451
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class SmachContainerInitialStatusCmd(_message.Message):
    __slots__ = ["path", "initial_states", "local_data"]
    PATH_FIELD_NUMBER: _ClassVar[int]
    INITIAL_STATES_FIELD_NUMBER: _ClassVar[int]
    LOCAL_DATA_FIELD_NUMBER: _ClassVar[int]
    path: str
    initial_states: _containers.RepeatedScalarFieldContainer[str]
    local_data: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, path: _Optional[str] = ..., initial_states: _Optional[_Iterable[str]] = ..., local_data: _Optional[_Iterable[int]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rtabmap_msgs/srv/get_map2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rtabmap_msgs.msg import map_data_pb2 as make87__messages__ros2_dot_jazzy_dot_rtabmap__msgs_dot_msg_dot_map__data__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:make87_messages_ros2/jazzy/rtabmap_msgs/srv/get_map2.proto\x12+make87_messages_ros2.jazzy.rtabmap_msgs.srv\x1a:make87_messages_ros2/jazzy/rtabmap_msgs/msg/map_data.proto\"\xc1\x01\n\x0eGetMap2Request\x12\x12\n\nglobal_map\x18\x01 \x01(\x08\x12\x11\n\toptimized\x18\x02 \x01(\x08\x12\x13\n\x0bwith_images\x18\x03 \x01(\x08\x12\x12\n\nwith_scans\x18\x04 \x01(\x08\x12\x16\n\x0ewith_user_data\x18\x05 \x01(\x08\x12\x12\n\nwith_grids\x18\x06 \x01(\x08\x12\x12\n\nwith_words\x18\x07 \x01(\x08\x12\x1f\n\x17with_global_descriptors\x18\x08 \x01(\x08\"U\n\x0fGetMap2Response\x12\x42\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x34.make87_messages_ros2.jazzy.rtabmap_msgs.msg.MapDatab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rtabmap_msgs.srv.get_map2_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETMAP2REQUEST']._serialized_start=168
  _globals['_GETMAP2REQUEST']._serialized_end=361
  _globals['_GETMAP2RESPONSE']._serialized_start=363
  _globals['_GETMAP2RESPONSE']._serialized_end=448
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.sick_safevisionary_interfaces.msg import io_configured_pb2 as _io_configured_pb2
from make87_messages_ros2.jazzy.sick_safevisionary_interfaces.msg import io_direction_pb2 as _io_direction_pb2
from make87_messages_ros2.jazzy.sick_safevisionary_interfaces.msg import io_input_values_pb2 as _io_input_values_pb2
from make87_messages_ros2.jazzy.sick_safevisionary_interfaces.msg import io_output_values_pb2 as _io_output_values_pb2
from make87_messages_ros2.jazzy.sick_safevisionary_interfaces.msg import ioossds_state_pb2 as _ioossds_state_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CameraIO(_message.Message):
    __slots__ = ["header", "configured", "direction", "input_values", "output_values", "ossds_state", "ossds_dyn_count", "ossds_crc", "ossds_io_status", "dynamic_speed_a", "dynamic_speed_b", "dynamic_valid_flags"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CONFIGURED_FIELD_NUMBER: _ClassVar[int]
    DIRECTION_FIELD_NUMBER: _ClassVar[int]
    INPUT_VALUES_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_VALUES_FIELD_NUMBER: _ClassVar[int]
    OSSDS_STATE_FIELD_NUMBER: _ClassVar[int]
    OSSDS_DYN_COUNT_FIELD_NUMBER: _ClassVar[int]
    OSSDS_CRC_FIELD_NUMBER: _ClassVar[int]
    OSSDS_IO_STATUS_FIELD_NUMBER: _ClassVar[int]
    DYNAMIC_SPEED_A_FIELD_NUMBER: _ClassVar[int]
    DYNAMIC_SPEED_B_FIELD_NUMBER: _ClassVar[int]
    DYNAMIC_VALID_FLAGS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    configured: _io_configured_pb2.IOConfigured
    direction: _io_direction_pb2.IODirection
    input_values: _io_input_values_pb2.IOInputValues
    output_values: _io_output_values_pb2.IOOutputValues
    ossds_state: _ioossds_state_pb2.IOOSSDSState
    ossds_dyn_count: int
    ossds_crc: int
    ossds_io_status: int
    dynamic_speed_a: int
    dynamic_speed_b: int
    dynamic_valid_flags: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., configured: _Optional[_Union[_io_configured_pb2.IOConfigured, _Mapping]] = ..., direction: _Optional[_Union[_io_direction_pb2.IODirection, _Mapping]] = ..., input_values: _Optional[_Union[_io_input_values_pb2.IOInputValues, _Mapping]] = ..., output_values: _Optional[_Union[_io_output_values_pb2.IOOutputValues, _Mapping]] = ..., ossds_state: _Optional[_Union[_ioossds_state_pb2.IOOSSDSState, _Mapping]] = ..., ossds_dyn_count: _Optional[int] = ..., ossds_crc: _Optional[int] = ..., ossds_io_status: _Optional[int] = ..., dynamic_speed_a: _Optional[int] = ..., dynamic_speed_b: _Optional[int] = ..., dynamic_valid_flags: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.rc_common_msgs.msg import return_code_pb2 as _return_code_pb2
from make87_messages_ros2.humble.rc_reason_msgs.msg import load_carrier_model_pb2 as _load_carrier_model_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetLoadCarrierRequest(_message.Message):
    __slots__ = ["header", "load_carrier"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    LOAD_CARRIER_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    load_carrier: _load_carrier_model_pb2.LoadCarrierModel
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., load_carrier: _Optional[_Union[_load_carrier_model_pb2.LoadCarrierModel, _Mapping]] = ...) -> None: ...

class SetLoadCarrierResponse(_message.Message):
    __slots__ = ["header", "return_code"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    RETURN_CODE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    return_code: _return_code_pb2.ReturnCode
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., return_code: _Optional[_Union[_return_code_pb2.ReturnCode, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ur_msgs/srv/set_speed_slider_fraction.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/rolling/ur_msgs/srv/set_speed_slider_fraction.proto\x12(make87_messages_ros2.rolling.ur_msgs.srv\">\n\x1dSetSpeedSliderFractionRequest\x12\x1d\n\x15speed_slider_fraction\x18\x01 \x01(\x01\"1\n\x1eSetSpeedSliderFractionResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ur_msgs.srv.set_speed_slider_fraction_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SETSPEEDSLIDERFRACTIONREQUEST']._serialized_start=118
  _globals['_SETSPEEDSLIDERFRACTIONREQUEST']._serialized_end=180
  _globals['_SETSPEEDSLIDERFRACTIONRESPONSE']._serialized_start=182
  _globals['_SETSPEEDSLIDERFRACTIONRESPONSE']._serialized_end=231
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rmf_traffic_msgs/msg/participants.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rmf_traffic_msgs.msg import participant_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__traffic__msgs_dot_msg_dot_participant__pb2
from make87_messages_ros2.jazzy.rmf_traffic_msgs.msg import schedule_identity_pb2 as make87__messages__ros2_dot_jazzy_dot_rmf__traffic__msgs_dot_msg_dot_schedule__identity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/jazzy/rmf_traffic_msgs/msg/participants.proto\x12/make87_messages_ros2.jazzy.rmf_traffic_msgs.msg\x1a\x41make87_messages_ros2/jazzy/rmf_traffic_msgs/msg/participant.proto\x1aGmake87_messages_ros2/jazzy/rmf_traffic_msgs/msg/schedule_identity.proto\"\xb6\x01\n\x0cParticipants\x12R\n\x07node_id\x18\x01 \x01(\x0b\x32\x41.make87_messages_ros2.jazzy.rmf_traffic_msgs.msg.ScheduleIdentity\x12R\n\x0cparticipants\x18\x02 \x03(\x0b\x32<.make87_messages_ros2.jazzy.rmf_traffic_msgs.msg.Participantb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rmf_traffic_msgs.msg.participants_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PARTICIPANTS']._serialized_start=260
  _globals['_PARTICIPANTS']._serialized_end=442
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.gazebo_msgs.msg import model_state_pb2 as _model_state_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetModelStateRequest(_message.Message):
    __slots__ = ["model_state"]
    MODEL_STATE_FIELD_NUMBER: _ClassVar[int]
    model_state: _model_state_pb2.ModelState
    def __init__(self, model_state: _Optional[_Union[_model_state_pb2.ModelState, _Mapping]] = ...) -> None: ...

class SetModelStateResponse(_message.Message):
    __slots__ = ["success", "status_message"]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    STATUS_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    status_message: str
    def __init__(self, success: bool = ..., status_message: _Optional[str] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ClockSteering(_message.Message):
    __slots__ = ["source", "steering_state", "period", "pulse_width", "bandwidth", "slope", "offset", "drift_rate"]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    STEERING_STATE_FIELD_NUMBER: _ClassVar[int]
    PERIOD_FIELD_NUMBER: _ClassVar[int]
    PULSE_WIDTH_FIELD_NUMBER: _ClassVar[int]
    BANDWIDTH_FIELD_NUMBER: _ClassVar[int]
    SLOPE_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    DRIFT_RATE_FIELD_NUMBER: _ClassVar[int]
    source: str
    steering_state: str
    period: int
    pulse_width: float
    bandwidth: float
    slope: float
    offset: float
    drift_rate: float
    def __init__(self, source: _Optional[str] = ..., steering_state: _Optional[str] = ..., period: _Optional[int] = ..., pulse_width: _Optional[float] = ..., bandwidth: _Optional[float] = ..., slope: _Optional[float] = ..., offset: _Optional[float] = ..., drift_rate: _Optional[float] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class UrdfRobot(_message.Message):
    __slots__ = ["name", "urdf_path", "robot_description", "relative_path_prefix", "translation", "rotation", "normal", "box_collision", "init_pos"]
    NAME_FIELD_NUMBER: _ClassVar[int]
    URDF_PATH_FIELD_NUMBER: _ClassVar[int]
    ROBOT_DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    RELATIVE_PATH_PREFIX_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_FIELD_NUMBER: _ClassVar[int]
    ROTATION_FIELD_NUMBER: _ClassVar[int]
    NORMAL_FIELD_NUMBER: _ClassVar[int]
    BOX_COLLISION_FIELD_NUMBER: _ClassVar[int]
    INIT_POS_FIELD_NUMBER: _ClassVar[int]
    name: str
    urdf_path: str
    robot_description: str
    relative_path_prefix: str
    translation: str
    rotation: str
    normal: bool
    box_collision: bool
    init_pos: str
    def __init__(self, name: _Optional[str] = ..., urdf_path: _Optional[str] = ..., robot_description: _Optional[str] = ..., relative_path_prefix: _Optional[str] = ..., translation: _Optional[str] = ..., rotation: _Optional[str] = ..., normal: bool = ..., box_collision: bool = ..., init_pos: _Optional[str] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class SpartnKeyInfo(_message.Message):
    __slots__ = ["reserved1", "key_length_bytes", "valid_from_wno", "valid_from_tow"]
    RESERVED1_FIELD_NUMBER: _ClassVar[int]
    KEY_LENGTH_BYTES_FIELD_NUMBER: _ClassVar[int]
    VALID_FROM_WNO_FIELD_NUMBER: _ClassVar[int]
    VALID_FROM_TOW_FIELD_NUMBER: _ClassVar[int]
    reserved1: int
    key_length_bytes: int
    valid_from_wno: int
    valid_from_tow: int
    def __init__(self, reserved1: _Optional[int] = ..., key_length_bytes: _Optional[int] = ..., valid_from_wno: _Optional[int] = ..., valid_from_tow: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class GimbalManagerSetPitchyaw(_message.Message):
    __slots__ = ["target_system", "target_component", "flags", "gimbal_device_id", "pitch", "yaw", "pitch_rate", "yaw_rate"]
    TARGET_SYSTEM_FIELD_NUMBER: _ClassVar[int]
    TARGET_COMPONENT_FIELD_NUMBER: _ClassVar[int]
    FLAGS_FIELD_NUMBER: _ClassVar[int]
    GIMBAL_DEVICE_ID_FIELD_NUMBER: _ClassVar[int]
    PITCH_FIELD_NUMBER: _ClassVar[int]
    YAW_FIELD_NUMBER: _ClassVar[int]
    PITCH_RATE_FIELD_NUMBER: _ClassVar[int]
    YAW_RATE_FIELD_NUMBER: _ClassVar[int]
    target_system: int
    target_component: int
    flags: int
    gimbal_device_id: int
    pitch: float
    yaw: float
    pitch_rate: float
    yaw_rate: float
    def __init__(self, target_system: _Optional[int] = ..., target_component: _Optional[int] = ..., flags: _Optional[int] = ..., gimbal_device_id: _Optional[int] = ..., pitch: _Optional[float] = ..., yaw: _Optional[float] = ..., pitch_rate: _Optional[float] = ..., yaw_rate: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rcl_interfaces/msg/parameter_event.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.jazzy.rcl_interfaces.msg import parameter_pb2 as make87__messages__ros2_dot_jazzy_dot_rcl__interfaces_dot_msg_dot_parameter__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/jazzy/rcl_interfaces/msg/parameter_event.proto\x12-make87_messages_ros2.jazzy.rcl_interfaces.msg\x1a<make87_messages_ros2/jazzy/builtin_interfaces/msg/time.proto\x1a=make87_messages_ros2/jazzy/rcl_interfaces/msg/parameter.proto\"\xe4\x02\n\x0eParameterEvent\x12\x46\n\x05stamp\x18\x01 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Time\x12\x0c\n\x04node\x18\x02 \x01(\t\x12P\n\x0enew_parameters\x18\x03 \x03(\x0b\x32\x38.make87_messages_ros2.jazzy.rcl_interfaces.msg.Parameter\x12T\n\x12\x63hanged_parameters\x18\x04 \x03(\x0b\x32\x38.make87_messages_ros2.jazzy.rcl_interfaces.msg.Parameter\x12T\n\x12\x64\x65leted_parameters\x18\x05 \x03(\x0b\x32\x38.make87_messages_ros2.jazzy.rcl_interfaces.msg.Parameterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rcl_interfaces.msg.parameter_event_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PARAMETEREVENT']._serialized_start=244
  _globals['_PARAMETEREVENT']._serialized_end=600
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rosbag2_interfaces/srv/burst.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/rolling/rosbag2_interfaces/srv/burst.proto\x12\x33make87_messages_ros2.rolling.rosbag2_interfaces.srv\"$\n\x0c\x42urstRequest\x12\x14\n\x0cnum_messages\x18\x01 \x01(\x04\"\'\n\rBurstResponse\x12\x16\n\x0e\x61\x63tually_burst\x18\x01 \x01(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rosbag2_interfaces.srv.burst_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BURSTREQUEST']._serialized_start=120
  _globals['_BURSTREQUEST']._serialized_end=156
  _globals['_BURSTRESPONSE']._serialized_start=158
  _globals['_BURSTRESPONSE']._serialized_end=197
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/system_modes_msgs/srv/change_mode.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/jazzy/system_modes_msgs/srv/change_mode.proto\x12\x30make87_messages_ros2.jazzy.system_modes_msgs.srv\"&\n\x11\x43hangeModeRequest\x12\x11\n\tmode_name\x18\x01 \x01(\t\"%\n\x12\x43hangeModeResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.system_modes_msgs.srv.change_mode_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_CHANGEMODEREQUEST']._serialized_start=120
  _globals['_CHANGEMODEREQUEST']._serialized_end=158
  _globals['_CHANGEMODERESPONSE']._serialized_start=160
  _globals['_CHANGEMODERESPONSE']._serialized_end=197
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NavSVIN(_message.Message):
    __slots__ = ["header", "version", "reserved0", "i_tow", "dur", "mean_x", "mean_y", "mean_z", "mean_xhp", "mean_yhp", "mean_zhp", "reserved1", "mean_acc", "obs", "valid", "active", "reserved3"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    RESERVED0_FIELD_NUMBER: _ClassVar[int]
    I_TOW_FIELD_NUMBER: _ClassVar[int]
    DUR_FIELD_NUMBER: _ClassVar[int]
    MEAN_X_FIELD_NUMBER: _ClassVar[int]
    MEAN_Y_FIELD_NUMBER: _ClassVar[int]
    MEAN_Z_FIELD_NUMBER: _ClassVar[int]
    MEAN_XHP_FIELD_NUMBER: _ClassVar[int]
    MEAN_YHP_FIELD_NUMBER: _ClassVar[int]
    MEAN_ZHP_FIELD_NUMBER: _ClassVar[int]
    RESERVED1_FIELD_NUMBER: _ClassVar[int]
    MEAN_ACC_FIELD_NUMBER: _ClassVar[int]
    OBS_FIELD_NUMBER: _ClassVar[int]
    VALID_FIELD_NUMBER: _ClassVar[int]
    ACTIVE_FIELD_NUMBER: _ClassVar[int]
    RESERVED3_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    version: int
    reserved0: _containers.RepeatedScalarFieldContainer[int]
    i_tow: int
    dur: int
    mean_x: int
    mean_y: int
    mean_z: int
    mean_xhp: int
    mean_yhp: int
    mean_zhp: int
    reserved1: int
    mean_acc: int
    obs: int
    valid: int
    active: int
    reserved3: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., version: _Optional[int] = ..., reserved0: _Optional[_Iterable[int]] = ..., i_tow: _Optional[int] = ..., dur: _Optional[int] = ..., mean_x: _Optional[int] = ..., mean_y: _Optional[int] = ..., mean_z: _Optional[int] = ..., mean_xhp: _Optional[int] = ..., mean_yhp: _Optional[int] = ..., mean_zhp: _Optional[int] = ..., reserved1: _Optional[int] = ..., mean_acc: _Optional[int] = ..., obs: _Optional[int] = ..., valid: _Optional[int] = ..., active: _Optional[int] = ..., reserved3: _Optional[_Iterable[int]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/tuw_geo_msgs/msg/geo_json_properties.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/rolling/tuw_geo_msgs/msg/geo_json_properties.proto\x12-make87_messages_ros2.rolling.tuw_geo_msgs.msg\"_\n\x11GeoJSONProperties\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0c\n\x04type\x18\x02 \x01(\r\x12\x18\n\x10\x65nflation_radius\x18\x03 \x03(\x01\x12\x16\n\x0e\x62ondary_radius\x18\x04 \x03(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.tuw_geo_msgs.msg.geo_json_properties_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GEOJSONPROPERTIES']._serialized_start=122
  _globals['_GEOJSONPROPERTIES']._serialized_end=217
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.septentrio_gnss_driver.msg import block_header_pb2 as _block_header_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class VelSensorSetup(_message.Message):
    __slots__ = ["header", "block_header", "port", "lever_arm_x", "lever_arm_y", "lever_arm_z"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BLOCK_HEADER_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    LEVER_ARM_X_FIELD_NUMBER: _ClassVar[int]
    LEVER_ARM_Y_FIELD_NUMBER: _ClassVar[int]
    LEVER_ARM_Z_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    block_header: _block_header_pb2.BlockHeader
    port: int
    lever_arm_x: float
    lever_arm_y: float
    lever_arm_z: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., block_header: _Optional[_Union[_block_header_pb2.BlockHeader, _Mapping]] = ..., port: _Optional[int] = ..., lever_arm_x: _Optional[float] = ..., lever_arm_y: _Optional[float] = ..., lever_arm_z: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.rolling.ros_gz_interfaces.msg import entity_pb2 as _entity_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DeleteEntityRequest(_message.Message):
    __slots__ = ["entity"]
    ENTITY_FIELD_NUMBER: _ClassVar[int]
    entity: _entity_pb2.Entity
    def __init__(self, entity: _Optional[_Union[_entity_pb2.Entity, _Mapping]] = ...) -> None: ...

class DeleteEntityResponse(_message.Message):
    __slots__ = ["success"]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class RenameRobotStateInWarehouseRequest(_message.Message):
    __slots__ = ["old_name", "new_name", "robot"]
    OLD_NAME_FIELD_NUMBER: _ClassVar[int]
    NEW_NAME_FIELD_NUMBER: _ClassVar[int]
    ROBOT_FIELD_NUMBER: _ClassVar[int]
    old_name: str
    new_name: str
    robot: str
    def __init__(self, old_name: _Optional[str] = ..., new_name: _Optional[str] = ..., robot: _Optional[str] = ...) -> None: ...

class RenameRobotStateInWarehouseResponse(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.autoware_planning_msgs.msg import path_point_pb2 as _path_point_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import point_pb2 as _point_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Path(_message.Message):
    __slots__ = ["header", "ros2_header", "points", "left_bound", "right_bound"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    POINTS_FIELD_NUMBER: _ClassVar[int]
    LEFT_BOUND_FIELD_NUMBER: _ClassVar[int]
    RIGHT_BOUND_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    points: _containers.RepeatedCompositeFieldContainer[_path_point_pb2.PathPoint]
    left_bound: _containers.RepeatedCompositeFieldContainer[_point_pb2.Point]
    right_bound: _containers.RepeatedCompositeFieldContainer[_point_pb2.Point]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., points: _Optional[_Iterable[_Union[_path_point_pb2.PathPoint, _Mapping]]] = ..., left_bound: _Optional[_Iterable[_Union[_point_pb2.Point, _Mapping]]] = ..., right_bound: _Optional[_Iterable[_Union[_point_pb2.Point, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/tuw_multi_robot_msgs/srv/station_manager_station_protocol.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.tuw_multi_robot_msgs.msg import station_pb2 as make87__messages__ros2_dot_humble_dot_tuw__multi__robot__msgs_dot_msg_dot_station__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n[make87_messages_ros2/humble/tuw_multi_robot_msgs/srv/station_manager_station_protocol.proto\x12\x34make87_messages_ros2.humble.tuw_multi_robot_msgs.srv\x1a!make87_messages/core/header.proto\x1a\x42make87_messages_ros2/humble/tuw_multi_robot_msgs/msg/station.proto\"\xb5\x01\n$StationManagerStationProtocolRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07request\x18\x02 \x01(\t\x12N\n\x07station\x18\x03 \x01(\x0b\x32=.make87_messages_ros2.humble.tuw_multi_robot_msgs.msg.Station\"g\n%StationManagerStationProtocolResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x10\n\x08response\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.tuw_multi_robot_msgs.srv.station_manager_station_protocol_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_STATIONMANAGERSTATIONPROTOCOLREQUEST']._serialized_start=253
  _globals['_STATIONMANAGERSTATIONPROTOCOLREQUEST']._serialized_end=434
  _globals['_STATIONMANAGERSTATIONPROTOCOLRESPONSE']._serialized_start=436
  _globals['_STATIONMANAGERSTATIONPROTOCOLRESPONSE']._serialized_end=539
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rcl_interfaces/msg/parameter_value.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nDmake87_messages_ros2/humble/rcl_interfaces/msg/parameter_value.proto\x12.make87_messages_ros2.humble.rcl_interfaces.msg\x1a!make87_messages/core/header.proto\"\xac\x02\n\x0eParameterValue\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0c\n\x04type\x18\x02 \x01(\r\x12\x12\n\nbool_value\x18\x03 \x01(\x08\x12\x15\n\rinteger_value\x18\x04 \x01(\x03\x12\x14\n\x0c\x64ouble_value\x18\x05 \x01(\x01\x12\x14\n\x0cstring_value\x18\x06 \x01(\t\x12\x18\n\x10\x62yte_array_value\x18\x07 \x03(\r\x12\x18\n\x10\x62ool_array_value\x18\x08 \x03(\x08\x12\x1b\n\x13integer_array_value\x18\t \x03(\x03\x12\x1a\n\x12\x64ouble_array_value\x18\n \x03(\x01\x12\x1a\n\x12string_array_value\x18\x0b \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rcl_interfaces.msg.parameter_value_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_PARAMETERVALUE']._serialized_start=156
  _globals['_PARAMETERVALUE']._serialized_end=456
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MonitorReport(_message.Message):
    __slots__ = ["header", "ros2_header", "fault", "shutoff", "shutoff_on_motion", "stationary", "fault_test", "fault_system", "fault_steer", "fault_brake", "fault_thrtl", "fault_gear", "fault_ulc", "fault_vehicle_velocity", "fault_steer_feedback", "fault_steer_input", "fault_steer_param", "fault_steer_limit", "fault_steer_override", "fault_steer_cmd", "fault_steer_cmd_rate", "fault_steer_cmd_en", "fault_steer_cmd_sys", "fault_steer_cmd_ovr", "fault_brake_feedback", "fault_brake_input", "fault_brake_param", "fault_brake_limit", "fault_brake_override", "fault_brake_cmd", "fault_brake_cmd_ulc", "fault_brake_cmd_en", "fault_brake_cmd_sys", "fault_brake_cmd_ovr", "fault_thrtl_feedback", "fault_thrtl_input", "fault_thrtl_param", "fault_thrtl_limit", "fault_thrtl_override", "fault_thrtl_cmd", "fault_thrtl_cmd_ulc", "fault_thrtl_cmd_en", "fault_thrtl_cmd_sys", "fault_thrtl_cmd_ovr", "fault_gear_feedback", "fault_gear_input", "fault_gear_param", "fault_gear_override", "fault_gear_cmd", "fault_gear_cmd_ulc", "fault_system_param", "steer_cmd_match_oem", "steer_cmd_match_dbw", "brake_cmd_match_oem", "brake_cmd_match_dbw", "thrtl_cmd_match_oem", "thrtl_cmd_match_dbw", "gear_cmd_match_oem", "gear_cmd_match_dbw"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    FAULT_FIELD_NUMBER: _ClassVar[int]
    SHUTOFF_FIELD_NUMBER: _ClassVar[int]
    SHUTOFF_ON_MOTION_FIELD_NUMBER: _ClassVar[int]
    STATIONARY_FIELD_NUMBER: _ClassVar[int]
    FAULT_TEST_FIELD_NUMBER: _ClassVar[int]
    FAULT_SYSTEM_FIELD_NUMBER: _ClassVar[int]
    FAULT_STEER_FIELD_NUMBER: _ClassVar[int]
    FAULT_BRAKE_FIELD_NUMBER: _ClassVar[int]
    FAULT_THRTL_FIELD_NUMBER: _ClassVar[int]
    FAULT_GEAR_FIELD_NUMBER: _ClassVar[int]
    FAULT_ULC_FIELD_NUMBER: _ClassVar[int]
    FAULT_VEHICLE_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    FAULT_STEER_FEEDBACK_FIELD_NUMBER: _ClassVar[int]
    FAULT_STEER_INPUT_FIELD_NUMBER: _ClassVar[int]
    FAULT_STEER_PARAM_FIELD_NUMBER: _ClassVar[int]
    FAULT_STEER_LIMIT_FIELD_NUMBER: _ClassVar[int]
    FAULT_STEER_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
    FAULT_STEER_CMD_FIELD_NUMBER: _ClassVar[int]
    FAULT_STEER_CMD_RATE_FIELD_NUMBER: _ClassVar[int]
    FAULT_STEER_CMD_EN_FIELD_NUMBER: _ClassVar[int]
    FAULT_STEER_CMD_SYS_FIELD_NUMBER: _ClassVar[int]
    FAULT_STEER_CMD_OVR_FIELD_NUMBER: _ClassVar[int]
    FAULT_BRAKE_FEEDBACK_FIELD_NUMBER: _ClassVar[int]
    FAULT_BRAKE_INPUT_FIELD_NUMBER: _ClassVar[int]
    FAULT_BRAKE_PARAM_FIELD_NUMBER: _ClassVar[int]
    FAULT_BRAKE_LIMIT_FIELD_NUMBER: _ClassVar[int]
    FAULT_BRAKE_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
    FAULT_BRAKE_CMD_FIELD_NUMBER: _ClassVar[int]
    FAULT_BRAKE_CMD_ULC_FIELD_NUMBER: _ClassVar[int]
    FAULT_BRAKE_CMD_EN_FIELD_NUMBER: _ClassVar[int]
    FAULT_BRAKE_CMD_SYS_FIELD_NUMBER: _ClassVar[int]
    FAULT_BRAKE_CMD_OVR_FIELD_NUMBER: _ClassVar[int]
    FAULT_THRTL_FEEDBACK_FIELD_NUMBER: _ClassVar[int]
    FAULT_THRTL_INPUT_FIELD_NUMBER: _ClassVar[int]
    FAULT_THRTL_PARAM_FIELD_NUMBER: _ClassVar[int]
    FAULT_THRTL_LIMIT_FIELD_NUMBER: _ClassVar[int]
    FAULT_THRTL_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
    FAULT_THRTL_CMD_FIELD_NUMBER: _ClassVar[int]
    FAULT_THRTL_CMD_ULC_FIELD_NUMBER: _ClassVar[int]
    FAULT_THRTL_CMD_EN_FIELD_NUMBER: _ClassVar[int]
    FAULT_THRTL_CMD_SYS_FIELD_NUMBER: _ClassVar[int]
    FAULT_THRTL_CMD_OVR_FIELD_NUMBER: _ClassVar[int]
    FAULT_GEAR_FEEDBACK_FIELD_NUMBER: _ClassVar[int]
    FAULT_GEAR_INPUT_FIELD_NUMBER: _ClassVar[int]
    FAULT_GEAR_PARAM_FIELD_NUMBER: _ClassVar[int]
    FAULT_GEAR_OVERRIDE_FIELD_NUMBER: _ClassVar[int]
    FAULT_GEAR_CMD_FIELD_NUMBER: _ClassVar[int]
    FAULT_GEAR_CMD_ULC_FIELD_NUMBER: _ClassVar[int]
    FAULT_SYSTEM_PARAM_FIELD_NUMBER: _ClassVar[int]
    STEER_CMD_MATCH_OEM_FIELD_NUMBER: _ClassVar[int]
    STEER_CMD_MATCH_DBW_FIELD_NUMBER: _ClassVar[int]
    BRAKE_CMD_MATCH_OEM_FIELD_NUMBER: _ClassVar[int]
    BRAKE_CMD_MATCH_DBW_FIELD_NUMBER: _ClassVar[int]
    THRTL_CMD_MATCH_OEM_FIELD_NUMBER: _ClassVar[int]
    THRTL_CMD_MATCH_DBW_FIELD_NUMBER: _ClassVar[int]
    GEAR_CMD_MATCH_OEM_FIELD_NUMBER: _ClassVar[int]
    GEAR_CMD_MATCH_DBW_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    fault: bool
    shutoff: bool
    shutoff_on_motion: bool
    stationary: bool
    fault_test: int
    fault_system: int
    fault_steer: int
    fault_brake: int
    fault_thrtl: int
    fault_gear: int
    fault_ulc: int
    fault_vehicle_velocity: int
    fault_steer_feedback: int
    fault_steer_input: int
    fault_steer_param: int
    fault_steer_limit: int
    fault_steer_override: int
    fault_steer_cmd: int
    fault_steer_cmd_rate: int
    fault_steer_cmd_en: int
    fault_steer_cmd_sys: int
    fault_steer_cmd_ovr: int
    fault_brake_feedback: int
    fault_brake_input: int
    fault_brake_param: int
    fault_brake_limit: int
    fault_brake_override: int
    fault_brake_cmd: int
    fault_brake_cmd_ulc: int
    fault_brake_cmd_en: int
    fault_brake_cmd_sys: int
    fault_brake_cmd_ovr: int
    fault_thrtl_feedback: int
    fault_thrtl_input: int
    fault_thrtl_param: int
    fault_thrtl_limit: int
    fault_thrtl_override: int
    fault_thrtl_cmd: int
    fault_thrtl_cmd_ulc: int
    fault_thrtl_cmd_en: int
    fault_thrtl_cmd_sys: int
    fault_thrtl_cmd_ovr: int
    fault_gear_feedback: int
    fault_gear_input: int
    fault_gear_param: int
    fault_gear_override: int
    fault_gear_cmd: int
    fault_gear_cmd_ulc: int
    fault_system_param: int
    steer_cmd_match_oem: bool
    steer_cmd_match_dbw: bool
    brake_cmd_match_oem: bool
    brake_cmd_match_dbw: bool
    thrtl_cmd_match_oem: bool
    thrtl_cmd_match_dbw: bool
    gear_cmd_match_oem: bool
    gear_cmd_match_dbw: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., fault: bool = ..., shutoff: bool = ..., shutoff_on_motion: bool = ..., stationary: bool = ..., fault_test: _Optional[int] = ..., fault_system: _Optional[int] = ..., fault_steer: _Optional[int] = ..., fault_brake: _Optional[int] = ..., fault_thrtl: _Optional[int] = ..., fault_gear: _Optional[int] = ..., fault_ulc: _Optional[int] = ..., fault_vehicle_velocity: _Optional[int] = ..., fault_steer_feedback: _Optional[int] = ..., fault_steer_input: _Optional[int] = ..., fault_steer_param: _Optional[int] = ..., fault_steer_limit: _Optional[int] = ..., fault_steer_override: _Optional[int] = ..., fault_steer_cmd: _Optional[int] = ..., fault_steer_cmd_rate: _Optional[int] = ..., fault_steer_cmd_en: _Optional[int] = ..., fault_steer_cmd_sys: _Optional[int] = ..., fault_steer_cmd_ovr: _Optional[int] = ..., fault_brake_feedback: _Optional[int] = ..., fault_brake_input: _Optional[int] = ..., fault_brake_param: _Optional[int] = ..., fault_brake_limit: _Optional[int] = ..., fault_brake_override: _Optional[int] = ..., fault_brake_cmd: _Optional[int] = ..., fault_brake_cmd_ulc: _Optional[int] = ..., fault_brake_cmd_en: _Optional[int] = ..., fault_brake_cmd_sys: _Optional[int] = ..., fault_brake_cmd_ovr: _Optional[int] = ..., fault_thrtl_feedback: _Optional[int] = ..., fault_thrtl_input: _Optional[int] = ..., fault_thrtl_param: _Optional[int] = ..., fault_thrtl_limit: _Optional[int] = ..., fault_thrtl_override: _Optional[int] = ..., fault_thrtl_cmd: _Optional[int] = ..., fault_thrtl_cmd_ulc: _Optional[int] = ..., fault_thrtl_cmd_en: _Optional[int] = ..., fault_thrtl_cmd_sys: _Optional[int] = ..., fault_thrtl_cmd_ovr: _Optional[int] = ..., fault_gear_feedback: _Optional[int] = ..., fault_gear_input: _Optional[int] = ..., fault_gear_param: _Optional[int] = ..., fault_gear_override: _Optional[int] = ..., fault_gear_cmd: _Optional[int] = ..., fault_gear_cmd_ulc: _Optional[int] = ..., fault_system_param: _Optional[int] = ..., steer_cmd_match_oem: bool = ..., steer_cmd_match_dbw: bool = ..., brake_cmd_match_oem: bool = ..., brake_cmd_match_dbw: bool = ..., thrtl_cmd_match_oem: bool = ..., thrtl_cmd_match_dbw: bool = ..., gear_cmd_match_oem: bool = ..., gear_cmd_match_dbw: bool = ...) -> None: ...



from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Lateral(_message.Message):
    __slots__ = ["stamp", "control_time", "steering_tire_angle", "steering_tire_rotation_rate", "is_defined_steering_tire_rotation_rate"]
    STAMP_FIELD_NUMBER: _ClassVar[int]
    CONTROL_TIME_FIELD_NUMBER: _ClassVar[int]
    STEERING_TIRE_ANGLE_FIELD_NUMBER: _ClassVar[int]
    STEERING_TIRE_ROTATION_RATE_FIELD_NUMBER: _ClassVar[int]
    IS_DEFINED_STEERING_TIRE_ROTATION_RATE_FIELD_NUMBER: _ClassVar[int]
    stamp: _time_pb2.Time
    control_time: _time_pb2.Time
    steering_tire_angle: float
    steering_tire_rotation_rate: float
    is_defined_steering_tire_rotation_rate: bool
    def __init__(self, stamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., control_time: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., steering_tire_angle: _Optional[float] = ..., steering_tire_rotation_rate: _Optional[float] = ..., is_defined_steering_tire_rotation_rate: bool = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class NavVELNED(_message.Message):
    __slots__ = ["i_tow", "vel_n", "vel_e", "vel_d", "speed", "g_speed", "heading", "s_acc", "c_acc"]
    I_TOW_FIELD_NUMBER: _ClassVar[int]
    VEL_N_FIELD_NUMBER: _ClassVar[int]
    VEL_E_FIELD_NUMBER: _ClassVar[int]
    VEL_D_FIELD_NUMBER: _ClassVar[int]
    SPEED_FIELD_NUMBER: _ClassVar[int]
    G_SPEED_FIELD_NUMBER: _ClassVar[int]
    HEADING_FIELD_NUMBER: _ClassVar[int]
    S_ACC_FIELD_NUMBER: _ClassVar[int]
    C_ACC_FIELD_NUMBER: _ClassVar[int]
    i_tow: int
    vel_n: int
    vel_e: int
    vel_d: int
    speed: int
    g_speed: int
    heading: int
    s_acc: int
    c_acc: int
    def __init__(self, i_tow: _Optional[int] = ..., vel_n: _Optional[int] = ..., vel_e: _Optional[int] = ..., vel_d: _Optional[int] = ..., speed: _Optional[int] = ..., g_speed: _Optional[int] = ..., heading: _Optional[int] = ..., s_acc: _Optional[int] = ..., c_acc: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EsrTrack(_message.Message):
    __slots__ = ["header", "canmsg", "id", "lat_rate", "grouping_changed", "oncoming", "status", "angle", "range", "bridge_object", "rolling_count", "width", "range_accel", "med_range_mode", "range_rate"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CANMSG_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    LAT_RATE_FIELD_NUMBER: _ClassVar[int]
    GROUPING_CHANGED_FIELD_NUMBER: _ClassVar[int]
    ONCOMING_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    ANGLE_FIELD_NUMBER: _ClassVar[int]
    RANGE_FIELD_NUMBER: _ClassVar[int]
    BRIDGE_OBJECT_FIELD_NUMBER: _ClassVar[int]
    ROLLING_COUNT_FIELD_NUMBER: _ClassVar[int]
    WIDTH_FIELD_NUMBER: _ClassVar[int]
    RANGE_ACCEL_FIELD_NUMBER: _ClassVar[int]
    MED_RANGE_MODE_FIELD_NUMBER: _ClassVar[int]
    RANGE_RATE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    canmsg: str
    id: int
    lat_rate: float
    grouping_changed: bool
    oncoming: bool
    status: int
    angle: float
    range: float
    bridge_object: bool
    rolling_count: bool
    width: float
    range_accel: float
    med_range_mode: int
    range_rate: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., canmsg: _Optional[str] = ..., id: _Optional[int] = ..., lat_rate: _Optional[float] = ..., grouping_changed: bool = ..., oncoming: bool = ..., status: _Optional[int] = ..., angle: _Optional[float] = ..., range: _Optional[float] = ..., bridge_object: bool = ..., rolling_count: bool = ..., width: _Optional[float] = ..., range_accel: _Optional[float] = ..., med_range_mode: _Optional[int] = ..., range_rate: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/cartographer_ros_msgs/srv/get_trajectory_states.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.cartographer_ros_msgs.msg import status_response_pb2 as make87__messages__ros2_dot_rolling_dot_cartographer__ros__msgs_dot_msg_dot_status__response__pb2
from make87_messages_ros2.rolling.cartographer_ros_msgs.msg import trajectory_states_pb2 as make87__messages__ros2_dot_rolling_dot_cartographer__ros__msgs_dot_msg_dot_trajectory__states__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRmake87_messages_ros2/rolling/cartographer_ros_msgs/srv/get_trajectory_states.proto\x12\x36make87_messages_ros2.rolling.cartographer_ros_msgs.srv\x1aLmake87_messages_ros2/rolling/cartographer_ros_msgs/msg/status_response.proto\x1aNmake87_messages_ros2/rolling/cartographer_ros_msgs/msg/trajectory_states.proto\"\x1c\n\x1aGetTrajectoryStatesRequest\"\xda\x01\n\x1bGetTrajectoryStatesResponse\x12V\n\x06status\x18\x01 \x01(\x0b\x32\x46.make87_messages_ros2.rolling.cartographer_ros_msgs.msg.StatusResponse\x12\x63\n\x11trajectory_states\x18\x02 \x01(\x0b\x32H.make87_messages_ros2.rolling.cartographer_ros_msgs.msg.TrajectoryStatesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.cartographer_ros_msgs.srv.get_trajectory_states_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GETTRAJECTORYSTATESREQUEST']._serialized_start=300
  _globals['_GETTRAJECTORYSTATESREQUEST']._serialized_end=328
  _globals['_GETTRAJECTORYSTATESRESPONSE']._serialized_start=331
  _globals['_GETTRAJECTORYSTATESRESPONSE']._serialized_end=549
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.jazzy.ublox_msgs.msg import nav_dgpssv_pb2 as _nav_dgpssv_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class NavDGPS(_message.Message):
    __slots__ = ["i_tow", "age", "base_id", "base_health", "num_ch", "status", "reserved1", "sv"]
    I_TOW_FIELD_NUMBER: _ClassVar[int]
    AGE_FIELD_NUMBER: _ClassVar[int]
    BASE_ID_FIELD_NUMBER: _ClassVar[int]
    BASE_HEALTH_FIELD_NUMBER: _ClassVar[int]
    NUM_CH_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    RESERVED1_FIELD_NUMBER: _ClassVar[int]
    SV_FIELD_NUMBER: _ClassVar[int]
    i_tow: int
    age: int
    base_id: int
    base_health: int
    num_ch: int
    status: int
    reserved1: int
    sv: _containers.RepeatedCompositeFieldContainer[_nav_dgpssv_pb2.NavDGPSSV]
    def __init__(self, i_tow: _Optional[int] = ..., age: _Optional[int] = ..., base_id: _Optional[int] = ..., base_health: _Optional[int] = ..., num_ch: _Optional[int] = ..., status: _Optional[int] = ..., reserved1: _Optional[int] = ..., sv: _Optional[_Iterable[_Union[_nav_dgpssv_pb2.NavDGPSSV, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rosidl_generator_py/msg/string_arrays.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/rolling/rosidl_generator_py/msg/string_arrays.proto\x12\x34make87_messages_ros2.rolling.rosidl_generator_py.msg\"\x97\x03\n\x0cStringArrays\x12$\n\x1cub_string_static_array_value\x18\x01 \x03(\t\x12 \n\x18ub_string_ub_array_value\x18\x02 \x03(\t\x12%\n\x1dub_string_dynamic_array_value\x18\x03 \x03(\t\x12\"\n\x1astring_dynamic_array_value\x18\x04 \x03(\t\x12!\n\x19string_static_array_value\x18\x05 \x03(\t\x12\"\n\x1astring_bounded_array_value\x18\x06 \x03(\t\x12&\n\x1e\x64\x65\x66_string_dynamic_array_value\x18\x07 \x03(\t\x12%\n\x1d\x64\x65\x66_string_static_array_value\x18\x08 \x03(\t\x12&\n\x1e\x64\x65\x66_string_bounded_array_value\x18\t \x03(\t\x12\x1a\n\x12\x64\x65\x66_various_quotes\x18\n \x03(\t\x12\x1a\n\x12\x64\x65\x66_various_commas\x18\x0b \x03(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rosidl_generator_py.msg.string_arrays_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_STRINGARRAYS']._serialized_start=131
  _globals['_STRINGARRAYS']._serialized_end=538
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rc_reason_msgs/srv/set_hand_eye_calibration.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_rolling_dot_geometry__msgs_dot_msg_dot_pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNmake87_messages_ros2/rolling/rc_reason_msgs/srv/set_hand_eye_calibration.proto\x12/make87_messages_ros2.rolling.rc_reason_msgs.srv\x1a\x39make87_messages_ros2/rolling/geometry_msgs/msg/pose.proto\"y\n\x1cSetHandEyeCalibrationRequest\x12\x42\n\x04pose\x18\x01 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.geometry_msgs.msg.Pose\x12\x15\n\rrobot_mounted\x18\x02 \x01(\x08\"Q\n\x1dSetHandEyeCalibrationResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x0f\n\x07message\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rc_reason_msgs.srv.set_hand_eye_calibration_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SETHANDEYECALIBRATIONREQUEST']._serialized_start=190
  _globals['_SETHANDEYECALIBRATIONREQUEST']._serialized_end=311
  _globals['_SETHANDEYECALIBRATIONRESPONSE']._serialized_start=313
  _globals['_SETHANDEYECALIBRATIONRESPONSE']._serialized_end=394
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ublox_msgs/msg/nav_cov.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/rolling/ublox_msgs/msg/nav_cov.proto\x12+make87_messages_ros2.rolling.ublox_msgs.msg\"\xda\x02\n\x06NavCOV\x12\r\n\x05i_tow\x18\x01 \x01(\r\x12\x0f\n\x07version\x18\x02 \x01(\r\x12\x15\n\rpos_cov_valid\x18\x03 \x01(\r\x12\x15\n\rvel_cov_valid\x18\x04 \x01(\r\x12\x12\n\nreserved_0\x18\x05 \x03(\r\x12\x12\n\npos_cov_nn\x18\x06 \x01(\x02\x12\x12\n\npos_cov_ne\x18\x07 \x01(\x02\x12\x12\n\npos_cov_nd\x18\x08 \x01(\x02\x12\x12\n\npos_cov_ee\x18\t \x01(\x02\x12\x12\n\npos_cov_ed\x18\n \x01(\x02\x12\x12\n\npos_cov_dd\x18\x0b \x01(\x02\x12\x12\n\nvel_cov_nn\x18\x0c \x01(\x02\x12\x12\n\nvel_cov_ne\x18\r \x01(\x02\x12\x12\n\nvel_cov_nd\x18\x0e \x01(\x02\x12\x12\n\nvel_cov_ee\x18\x0f \x01(\x02\x12\x12\n\nvel_cov_ed\x18\x10 \x01(\x02\x12\x12\n\nvel_cov_dd\x18\x11 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ublox_msgs.msg.nav_cov_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_NAVCOV']._serialized_start=107
  _globals['_NAVCOV']._serialized_end=453
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class NavTIMEGPS(_message.Message):
    __slots__ = ["i_tow", "f_tow", "week", "leap_s", "valid", "t_acc"]
    I_TOW_FIELD_NUMBER: _ClassVar[int]
    F_TOW_FIELD_NUMBER: _ClassVar[int]
    WEEK_FIELD_NUMBER: _ClassVar[int]
    LEAP_S_FIELD_NUMBER: _ClassVar[int]
    VALID_FIELD_NUMBER: _ClassVar[int]
    T_ACC_FIELD_NUMBER: _ClassVar[int]
    i_tow: int
    f_tow: int
    week: int
    leap_s: int
    valid: int
    t_acc: int
    def __init__(self, i_tow: _Optional[int] = ..., f_tow: _Optional[int] = ..., week: _Optional[int] = ..., leap_s: _Optional[int] = ..., valid: _Optional[int] = ..., t_acc: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.jazzy.sbg_driver.msg import sbg_utc_time_status_pb2 as _sbg_utc_time_status_pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SbgUtcTime(_message.Message):
    __slots__ = ["header", "time_stamp", "clock_status", "year", "month", "day", "hour", "min", "sec", "nanosec", "gps_tow", "clk_bias_std", "clk_sf_error_std", "clk_residual_error"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TIME_STAMP_FIELD_NUMBER: _ClassVar[int]
    CLOCK_STATUS_FIELD_NUMBER: _ClassVar[int]
    YEAR_FIELD_NUMBER: _ClassVar[int]
    MONTH_FIELD_NUMBER: _ClassVar[int]
    DAY_FIELD_NUMBER: _ClassVar[int]
    HOUR_FIELD_NUMBER: _ClassVar[int]
    MIN_FIELD_NUMBER: _ClassVar[int]
    SEC_FIELD_NUMBER: _ClassVar[int]
    NANOSEC_FIELD_NUMBER: _ClassVar[int]
    GPS_TOW_FIELD_NUMBER: _ClassVar[int]
    CLK_BIAS_STD_FIELD_NUMBER: _ClassVar[int]
    CLK_SF_ERROR_STD_FIELD_NUMBER: _ClassVar[int]
    CLK_RESIDUAL_ERROR_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    time_stamp: int
    clock_status: _sbg_utc_time_status_pb2.SbgUtcTimeStatus
    year: int
    month: int
    day: int
    hour: int
    min: int
    sec: int
    nanosec: int
    gps_tow: int
    clk_bias_std: float
    clk_sf_error_std: float
    clk_residual_error: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., time_stamp: _Optional[int] = ..., clock_status: _Optional[_Union[_sbg_utc_time_status_pb2.SbgUtcTimeStatus, _Mapping]] = ..., year: _Optional[int] = ..., month: _Optional[int] = ..., day: _Optional[int] = ..., hour: _Optional[int] = ..., min: _Optional[int] = ..., sec: _Optional[int] = ..., nanosec: _Optional[int] = ..., gps_tow: _Optional[int] = ..., clk_bias_std: _Optional[float] = ..., clk_sf_error_std: _Optional[float] = ..., clk_residual_error: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rtabmap_msgs/msg/scan_descriptor.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.rtabmap_msgs.msg import global_descriptor_pb2 as make87__messages__ros2_dot_jazzy_dot_rtabmap__msgs_dot_msg_dot_global__descriptor__pb2
from make87_messages_ros2.jazzy.sensor_msgs.msg import laser_scan_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_laser__scan__pb2
from make87_messages_ros2.jazzy.sensor_msgs.msg import point_cloud2_pb2 as make87__messages__ros2_dot_jazzy_dot_sensor__msgs_dot_msg_dot_point__cloud2__pb2
from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/rtabmap_msgs/msg/scan_descriptor.proto\x12+make87_messages_ros2.jazzy.rtabmap_msgs.msg\x1a\x43make87_messages_ros2/jazzy/rtabmap_msgs/msg/global_descriptor.proto\x1a;make87_messages_ros2/jazzy/sensor_msgs/msg/laser_scan.proto\x1a=make87_messages_ros2/jazzy/sensor_msgs/msg/point_cloud2.proto\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xbd\x02\n\x0eScanDescriptor\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x43\n\x04scan\x18\x02 \x01(\x0b\x32\x35.make87_messages_ros2.jazzy.sensor_msgs.msg.LaserScan\x12K\n\nscan_cloud\x18\x03 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.sensor_msgs.msg.PointCloud2\x12X\n\x11global_descriptor\x18\x04 \x01(\x0b\x32=.make87_messages_ros2.jazzy.rtabmap_msgs.msg.GlobalDescriptorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rtabmap_msgs.msg.scan_descriptor_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SCANDESCRIPTOR']._serialized_start=362
  _globals['_SCANDESCRIPTOR']._serialized_end=679
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/delphi_srr_msgs/msg/srr_status2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBmake87_messages_ros2/rolling/delphi_srr_msgs/msg/srr_status2.proto\x12\x30make87_messages_ros2.rolling.delphi_srr_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\"\xeb\x03\n\nSrrStatus2\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x1f\n\x17\x63\x61n_tx_alignment_status\x18\x02 \x01(\r\x12\x19\n\x11\x63\x61n_tx_comm_error\x18\x03 \x01(\x08\x12\"\n\x1a\x63\x61n_tx_steering_angle_sign\x18\x04 \x01(\x08\x12\x1c\n\x14\x63\x61n_tx_yaw_rate_bias\x18\x05 \x01(\x02\x12\"\n\x1a\x63\x61n_tx_veh_spd_comp_factor\x18\x06 \x01(\x02\x12\x1d\n\x15\x63\x61n_tx_sw_version_dsp\x18\x07 \x01(\r\x12\x1a\n\x12\x63\x61n_tx_temperature\x18\x08 \x01(\x05\x12\x1f\n\x17\x63\x61n_tx_range_perf_error\x18\t \x01(\x08\x12\x1d\n\x15\x63\x61n_tx_overheat_error\x18\n \x01(\x08\x12\x1d\n\x15\x63\x61n_tx_internal_error\x18\x0b \x01(\x08\x12\x1f\n\x17\x63\x61n_tx_xcvr_operational\x18\x0c \x01(\x08\x12\x1d\n\x15\x63\x61n_tx_steering_angle\x18\r \x01(\r\x12\x1e\n\x16\x63\x61n_tx_rolling_count_2\x18\x0e \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.delphi_srr_msgs.msg.srr_status2_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SRRSTATUS2']._serialized_start=177
  _globals['_SRRSTATUS2']._serialized_end=668
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class RequestHeader(_message.Message):
    __slots__ = ["robot_name", "fleet_name", "request_id"]
    ROBOT_NAME_FIELD_NUMBER: _ClassVar[int]
    FLEET_NAME_FIELD_NUMBER: _ClassVar[int]
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    robot_name: str
    fleet_name: str
    request_id: int
    def __init__(self, robot_name: _Optional[str] = ..., fleet_name: _Optional[str] = ..., request_id: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.marker_msgs.msg import fiducial_pb2 as _fiducial_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FiducialDetection(_message.Message):
    __slots__ = ["header", "ros2_header", "camera_d", "camera_k", "type", "fiducial"]
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    CAMERA_D_FIELD_NUMBER: _ClassVar[int]
    CAMERA_K_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    FIDUCIAL_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    camera_d: _containers.RepeatedScalarFieldContainer[float]
    camera_k: _containers.RepeatedScalarFieldContainer[float]
    type: str
    fiducial: _containers.RepeatedCompositeFieldContainer[_fiducial_pb2.Fiducial]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., camera_d: _Optional[_Iterable[float]] = ..., camera_k: _Optional[_Iterable[float]] = ..., type: _Optional[str] = ..., fiducial: _Optional[_Iterable[_Union[_fiducial_pb2.Fiducial, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/turtlesim_msgs/srv/spawn.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/rolling/turtlesim_msgs/srv/spawn.proto\x12/make87_messages_ros2.rolling.turtlesim_msgs.srv\"A\n\x0cSpawnRequest\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\r\n\x05theta\x18\x03 \x01(\x02\x12\x0c\n\x04name\x18\x04 \x01(\t\"\x1d\n\rSpawnResponse\x12\x0c\n\x04name\x18\x01 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.turtlesim_msgs.srv.spawn_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SPAWNREQUEST']._serialized_start=112
  _globals['_SPAWNREQUEST']._serialized_end=177
  _globals['_SPAWNRESPONSE']._serialized_start=179
  _globals['_SPAWNRESPONSE']._serialized_end=208
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/gc_spl_interfaces/msg/rcgcrd4.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>make87_messages_ros2/jazzy/gc_spl_interfaces/msg/rcgcrd4.proto\x12\x30make87_messages_ros2.jazzy.gc_spl_interfaces.msg\"m\n\x07RCGCRD4\x12\x12\n\nplayer_num\x18\x01 \x01(\r\x12\x10\n\x08team_num\x18\x02 \x01(\r\x12\x0e\n\x06\x66\x61llen\x18\x03 \x01(\r\x12\x0c\n\x04pose\x18\x04 \x03(\x02\x12\x10\n\x08\x62\x61ll_age\x18\x05 \x01(\x02\x12\x0c\n\x04\x62\x61ll\x18\x06 \x03(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.gc_spl_interfaces.msg.rcgcrd4_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_RCGCRD4']._serialized_start=116
  _globals['_RCGCRD4']._serialized_end=225
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_traffic_msgs/msg/blockade_heartbeat.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import blockade_status_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__traffic__msgs_dot_msg_dot_blockade__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/rolling/rmf_traffic_msgs/msg/blockade_heartbeat.proto\x12\x31make87_messages_ros2.rolling.rmf_traffic_msgs.msg\x1aGmake87_messages_ros2/rolling/rmf_traffic_msgs/msg/blockade_status.proto\"~\n\x11\x42lockadeHeartbeat\x12S\n\x08statuses\x18\x01 \x03(\x0b\x32\x41.make87_messages_ros2.rolling.rmf_traffic_msgs.msg.BlockadeStatus\x12\x14\n\x0chas_gridlock\x18\x02 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_traffic_msgs.msg.blockade_heartbeat_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_BLOCKADEHEARTBEAT']._serialized_start=202
  _globals['_BLOCKADEHEARTBEAT']._serialized_end=328
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/mavros_msgs/srv/gimbal_manager_set_roi.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/humble/mavros_msgs/srv/gimbal_manager_set_roi.proto\x12+make87_messages_ros2.humble.mavros_msgs.srv\x1a!make87_messages/core/header.proto\"\xf7\x01\n\x1aGimbalManagerSetRoiRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0c\n\x04mode\x18\x02 \x01(\r\x12\x18\n\x10gimbal_device_id\x18\x03 \x01(\r\x12\x10\n\x08latitude\x18\x04 \x01(\x02\x12\x11\n\tlongitude\x18\x05 \x01(\x02\x12\x10\n\x08\x61ltitude\x18\x06 \x01(\x02\x12\x14\n\x0cpitch_offset\x18\x07 \x01(\x02\x12\x13\n\x0broll_offset\x18\x08 \x01(\x02\x12\x12\n\nyaw_offset\x18\t \x01(\x02\x12\r\n\x05sysid\x18\n \x01(\r\"l\n\x1bGimbalManagerSetRoiResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x0e\n\x06result\x18\x03 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.mavros_msgs.srv.gimbal_manager_set_roi_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_GIMBALMANAGERSETROIREQUEST']._serialized_start=157
  _globals['_GIMBALMANAGERSETROIREQUEST']._serialized_end=404
  _globals['_GIMBALMANAGERSETROIRESPONSE']._serialized_start=406
  _globals['_GIMBALMANAGERSETROIRESPONSE']._serialized_end=514
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/mavros_msgs/srv/file_list.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.mavros_msgs.msg import file_entry_pb2 as make87__messages__ros2_dot_humble_dot_mavros__msgs_dot_msg_dot_file__entry__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;make87_messages_ros2/humble/mavros_msgs/srv/file_list.proto\x12+make87_messages_ros2.humble.mavros_msgs.srv\x1a!make87_messages/core/header.proto\x1a<make87_messages_ros2/humble/mavros_msgs/msg/file_entry.proto\"Q\n\x0f\x46ileListRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x10\n\x08\x64ir_path\x18\x02 \x01(\t\"\xa8\x01\n\x10\x46ileListResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x44\n\x04list\x18\x02 \x03(\x0b\x32\x36.make87_messages_ros2.humble.mavros_msgs.msg.FileEntry\x12\x0f\n\x07success\x18\x03 \x01(\x08\x12\x0f\n\x07r_errno\x18\x04 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.mavros_msgs.srv.file_list_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_FILELISTREQUEST']._serialized_start=205
  _globals['_FILELISTREQUEST']._serialized_end=286
  _globals['_FILELISTRESPONSE']._serialized_start=289
  _globals['_FILELISTRESPONSE']._serialized_end=457
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ur_msgs/srv/set_analog_output.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.ur_msgs.msg import analog_pb2 as make87__messages__ros2_dot_rolling_dot_ur__msgs_dot_msg_dot_analog__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@make87_messages_ros2/rolling/ur_msgs/srv/set_analog_output.proto\x12(make87_messages_ros2.rolling.ur_msgs.srv\x1a\x35make87_messages_ros2/rolling/ur_msgs/msg/analog.proto\"X\n\x16SetAnalogOutputRequest\x12>\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x30.make87_messages_ros2.rolling.ur_msgs.msg.Analog\"*\n\x17SetAnalogOutputResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ur_msgs.srv.set_analog_output_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SETANALOGOUTPUTREQUEST']._serialized_start=165
  _globals['_SETANALOGOUTPUTREQUEST']._serialized_end=253
  _globals['_SETANALOGOUTPUTRESPONSE']._serialized_start=255
  _globals['_SETANALOGOUTPUTRESPONSE']._serialized_end=297
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ublox_ubx_msgs/msg/ubx_nav_rel_pos_ned.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_rolling_dot_std__msgs_dot_msg_dot_header__pb2
from make87_messages_ros2.rolling.ublox_ubx_msgs.msg import carr_soln_pb2 as make87__messages__ros2_dot_rolling_dot_ublox__ubx__msgs_dot_msg_dot_carr__soln__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nImake87_messages_ros2/rolling/ublox_ubx_msgs/msg/ubx_nav_rel_pos_ned.proto\x12/make87_messages_ros2.rolling.ublox_ubx_msgs.msg\x1a\x36make87_messages_ros2/rolling/std_msgs/msg/header.proto\x1a?make87_messages_ros2/rolling/ublox_ubx_msgs/msg/carr_soln.proto\"\xaf\x05\n\x0fUBXNavRelPosNED\x12\x41\n\x06header\x18\x01 \x01(\x0b\x32\x31.make87_messages_ros2.rolling.std_msgs.msg.Header\x12\x0f\n\x07version\x18\x02 \x01(\r\x12\x16\n\x0eref_station_id\x18\x03 \x01(\r\x12\x0c\n\x04itow\x18\x04 \x01(\r\x12\x11\n\trel_pos_n\x18\x05 \x01(\x05\x12\x11\n\trel_pos_e\x18\x06 \x01(\x05\x12\x11\n\trel_pos_d\x18\x07 \x01(\x05\x12\x16\n\x0erel_pos_length\x18\x08 \x01(\x05\x12\x17\n\x0frel_pos_heading\x18\t \x01(\x05\x12\x14\n\x0crel_pos_hp_n\x18\n \x01(\x05\x12\x14\n\x0crel_pos_hp_e\x18\x0b \x01(\x05\x12\x14\n\x0crel_pos_hp_d\x18\x0c \x01(\x05\x12\x19\n\x11rel_pos_hp_length\x18\r \x01(\x05\x12\r\n\x05\x61\x63\x63_n\x18\x0e \x01(\r\x12\r\n\x05\x61\x63\x63_e\x18\x0f \x01(\r\x12\r\n\x05\x61\x63\x63_d\x18\x10 \x01(\r\x12\x12\n\nacc_length\x18\x11 \x01(\r\x12\x13\n\x0b\x61\x63\x63_heading\x18\x12 \x01(\r\x12\x13\n\x0bgnss_fix_ok\x18\x13 \x01(\x08\x12\x11\n\tdiff_soln\x18\x14 \x01(\x08\x12\x15\n\rrel_pos_valid\x18\x15 \x01(\x08\x12L\n\tcarr_soln\x18\x16 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.ublox_ubx_msgs.msg.CarrSoln\x12\x11\n\tis_moving\x18\x17 \x01(\x08\x12\x14\n\x0cref_pos_miss\x18\x18 \x01(\x08\x12\x14\n\x0cref_obs_miss\x18\x19 \x01(\x08\x12\x1d\n\x15rel_pos_heading_valid\x18\x1a \x01(\x08\x12\x1a\n\x12rel_pos_normalized\x18\x1b \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ublox_ubx_msgs.msg.ubx_nav_rel_pos_ned_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_UBXNAVRELPOSNED']._serialized_start=248
  _globals['_UBXNAVRELPOSNED']._serialized_end=935
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class ScanPoint(_message.Message):
    __slots__ = ["angle", "distance", "reflectivity", "valid", "infinite", "glare", "reflector", "contamination", "contamination_warning"]
    ANGLE_FIELD_NUMBER: _ClassVar[int]
    DISTANCE_FIELD_NUMBER: _ClassVar[int]
    REFLECTIVITY_FIELD_NUMBER: _ClassVar[int]
    VALID_FIELD_NUMBER: _ClassVar[int]
    INFINITE_FIELD_NUMBER: _ClassVar[int]
    GLARE_FIELD_NUMBER: _ClassVar[int]
    REFLECTOR_FIELD_NUMBER: _ClassVar[int]
    CONTAMINATION_FIELD_NUMBER: _ClassVar[int]
    CONTAMINATION_WARNING_FIELD_NUMBER: _ClassVar[int]
    angle: float
    distance: int
    reflectivity: int
    valid: bool
    infinite: bool
    glare: bool
    reflector: bool
    contamination: bool
    contamination_warning: bool
    def __init__(self, angle: _Optional[float] = ..., distance: _Optional[int] = ..., reflectivity: _Optional[int] = ..., valid: bool = ..., infinite: bool = ..., glare: bool = ..., reflector: bool = ..., contamination: bool = ..., contamination_warning: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/marine_acoustic_msgs/msg/sonar_image_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/jazzy/marine_acoustic_msgs/msg/sonar_image_data.proto\x12\x33make87_messages_ros2.jazzy.marine_acoustic_msgs.msg\"W\n\x0eSonarImageData\x12\x14\n\x0cis_bigendian\x18\x01 \x01(\x08\x12\r\n\x05\x64type\x18\x02 \x01(\r\x12\x12\n\nbeam_count\x18\x03 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x04 \x03(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.marine_acoustic_msgs.msg.sonar_image_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_SONARIMAGEDATA']._serialized_start=131
  _globals['_SONARIMAGEDATA']._serialized_end=218
# @@protoc_insertion_point(module_scope)
